PredicateValue

Enum PredicateValue 

#[non_exhaustive]
pub enum PredicateValue { Numeric(f64), Integer(i64), String(String), }
The value side of a scan predicate.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Numeric(f64)

A numeric threshold (f64 for float columns, or integral f64 for i64 columns whose value fits within ±2^53 exactly).



Integer(i64)

An exact integer threshold for i64/timestamp columns.

When the planner knows the predicate value is an integer it should use this variant so that values outside ±2^53 are compared losslessly against BlockStats.min_i64/max_i64.



String(String)

A string threshold for lexicographic comparison.