pub struct ScanPredicate {
pub col_idx: usize,
pub op: PredicateOp,
pub value: PredicateValue,
}Expand description
A predicate on a single column for block-level pushdown.
Fields
col_idx: usizeColumn index in the schema.
op: PredicateOpThe comparison operation.
value: PredicateValueThe threshold value.
Implementations
Sourceimpl ScanPredicate
impl ScanPredicate
Sourcepub fn not_eq(col_idx: usize, value: f64) -> Self
pub fn not_eq(col_idx: usize, value: f64) -> Self
Create a predicate: column != value (numeric).
Named not_eq to avoid conflict with PartialEq::ne.
Sourcepub fn eq_i64(col_idx: usize, value: i64) -> Self
pub fn eq_i64(col_idx: usize, value: i64) -> Self
Create a predicate: column = value (exact integer, lossless for i64/timestamp).
Sourcepub fn not_eq_i64(col_idx: usize, value: i64) -> Self
pub fn not_eq_i64(col_idx: usize, value: i64) -> Self
Create a predicate: column != value (exact integer).
Sourcepub fn gt_i64(col_idx: usize, value: i64) -> Self
pub fn gt_i64(col_idx: usize, value: i64) -> Self
Create a predicate: column > value (exact integer).
Sourcepub fn gte_i64(col_idx: usize, value: i64) -> Self
pub fn gte_i64(col_idx: usize, value: i64) -> Self
Create a predicate: column >= value (exact integer).
Sourcepub fn lt_i64(col_idx: usize, value: i64) -> Self
pub fn lt_i64(col_idx: usize, value: i64) -> Self
Create a predicate: column < value (exact integer).
Sourcepub fn lte_i64(col_idx: usize, value: i64) -> Self
pub fn lte_i64(col_idx: usize, value: i64) -> Self
Create a predicate: column <= value (exact integer).
Sourcepub fn str_eq(col_idx: usize, value: impl Into<String>) -> Self
pub fn str_eq(col_idx: usize, value: impl Into<String>) -> Self
Create a predicate: column = value (string, lexicographic).
Sourcepub fn str_not_eq(col_idx: usize, value: impl Into<String>) -> Self
pub fn str_not_eq(col_idx: usize, value: impl Into<String>) -> Self
Create a predicate: column != value (string, lexicographic).
Sourcepub fn str_gt(col_idx: usize, value: impl Into<String>) -> Self
pub fn str_gt(col_idx: usize, value: impl Into<String>) -> Self
Create a predicate: column > value (string, lexicographic).
Sourcepub fn str_gte(col_idx: usize, value: impl Into<String>) -> Self
pub fn str_gte(col_idx: usize, value: impl Into<String>) -> Self
Create a predicate: column >= value (string, lexicographic).
Sourcepub fn str_lt(col_idx: usize, value: impl Into<String>) -> Self
pub fn str_lt(col_idx: usize, value: impl Into<String>) -> Self
Create a predicate: column < value (string, lexicographic).
Sourcepub fn str_lte(col_idx: usize, value: impl Into<String>) -> Self
pub fn str_lte(col_idx: usize, value: impl Into<String>) -> Self
Create a predicate: column <= value (string, lexicographic).
Sourcepub fn can_skip_block(&self, stats: &BlockStats) -> bool
pub fn can_skip_block(&self, stats: &BlockStats) -> bool
Whether a block can be entirely skipped based on its statistics.
Returns true if the block provably contains no matching rows.
Returns false if the block might contain matching rows (must scan).