Module reader
nodedb_
columnar
0.2.1
Module reader
Module Items
Structs
Enums
In crate nodedb_
columnar
nodedb_columnar
Module
reader
Structs

Owned
Segment
Reader
An owned segment reader that holds decrypted segment bytes.
Segment
Reader
Reads and decodes columns from a segment byte buffer.
Enums

Decoded
Column
Decoded column data from a segment scan.